lotttools = {}

local modpath = minetest.get_modpath("lotttools")
dofile(modpath .. "/craftitems.lua")

lotttools.heads = {
	iron = {
		ingredient = "lottores:iron_lump",
		uses = 10,
		speed = {[1] = 2, [2] = 3.5},
	},
	flint = {
		ingredient = "lottitems:flint",
		uses = 3,
		speed = {[1] = 3},
	},
	stone = {
		ingredient = "group:cobble",
		uses = 7,
		speed = {[1] = 2.5},
	},
	wood = {
		ingredient = "group:planks",
		uses = 5,
		speed = {[1] = 4},
	},
}

lotttools.bindings = {
	flint = {
		material = "lottitems:flint",
		uses = 2,
		speed = 0.2,
	},
	twine = {
		material = "lottitems:twine",
		uses = -2,
		speed = -0.3,
	},
	stick = {
		material = "lottitems:stick",
		uses = -1,
		speed = 0,
	},
	lead_peg = {
		material = "lottitems:lead",
		uses = 10,
		speed = 5,
	},
	iron_peg = {
		material = "lottitems:iron",
		uses = 5,
		speed = 0.3,
	},
}

lotttools.handles = {
	stick = {
		material = "lottitems:stick",
		uses = -1,
		speed = 0,
	},
	--planks = "lottitems:planks",
	--stone = "lottitems:cobble",
}

for head, head_values in pairs(lotttools.heads) do
for binding, binding_values in pairs(lotttools.bindings) do
for handle, handle_values in pairs(lotttools.handles) do
	local uses = head_values.uses + binding_values.uses + handle_values.uses
	local times = head_values.speed
	for i, v in pairs(times) do
		times[i] = v + binding_values.speed + handle_values.speed
	end
	--print(dump(times))
	minetest.register_tool("lotttools:" .. head .. "_" .. binding .. "_" ..
			handle .. "_pickaxe", {
		description = lott.str_to_desc(head) .. " Pickaxe\n  " ..
			lott.str_to_desc(handle) .. " Handle\n  " ..
			lott.str_to_desc(binding) .. " Binding",
		inventory_image = "lotttools_" .. handle .. "_handle.png^lotttools_" ..
			head .. "_head.png^lotttools_" .. binding .. "_binding.png",
		tool_capabilities = {
			full_punch_interval = 1.5,
			max_drop_level = 1,
			groupcaps = {
				pickaxe = {maxlevel = 0, uses = uses, times = times}
			},
		}
	})
	--print(head .. "_" .. binding .. "_" ..
	--		handle .. "_pickaxe")
end
end
end

local function tool_form(uses, speed, craftable)
	local uses_string = "label[2,5;N/A]"
	if uses then
		uses_string = "label[2,5;" .. uses .. "]"
	end
	local tier_string = "label[2,4.55;4]"
	local speed_string = "label[2,5.5;N/A]"
	if speed then
		speed_string = "label[2,5.5;" .. speed .. "]"
	end
	local craft_button = ""
	craftable = true
	if craftable then
		craft_button = "button[1,6;3,1;craft_me;Craft]"
	end
	return "real_coordinates[true]" ..
		"label[0.1,0.6;Binding:]" ..
		"list[current_name;tool_binding;2.5,0.1;1,1;]" ..
		"label[0.1,1.7;Head:]" ..
		"list[current_name;tool_head;2.5,1.2;1,1;]" ..
		"label[0.1,2.8;Handle:]" ..
		"list[current_name;tool_handle;2.5,2.3;1,1;]" ..
		"label[0.9,4;" .. minetest.colorize("red", "Stats:") .. "]" ..
		"label[0.4,4.5;" .. minetest.colorize("green", "Tier:") .. "]" ..
		"label[0.4,5;" .. minetest.colorize("green", "Uses:") .. "]" ..
		"label[0.4,5.5;" .. minetest.colorize("green", "Speed:") .. "]" ..
		"item_image[3.5,4.75;1,1;lotttools:iron_stick_stick_pickaxe]" ..
		uses_string .. speed_string .. tier_string .. craft_button
end

minetest.register_node("lotttools:tool_crafting_station", {
	description = "Tool Crafting Station",
	tiles = {"lottplants_oak_planks.png", "lottplants_dark_oak_planks.png", "lottplants_maple_planks.png"},
	on_construct = function(pos)
		local meta = minetest.get_meta(pos)
		meta:set_string("formspec", lottplayer.inv_size("4x6") .. tool_form())

		local inv = meta:get_inventory()
		inv:set_size("tool_head", 1)
		inv:set_size("tool_handle", 1)
		inv:set_size("tool_binding", 1)
	end,
	on_rightclick = function(pos, node, clicker)
		local name = clicker:get_player_name()
		local meta = minetest.get_meta(pos)
		meta:set_string("formspec",
			lottplayer.inv_size("4x6") .. lottplayer.inv(clicker) .. tool_form())
	end,
	on_receive_fields = function(pos, formname, fields, sender)
		local meta = minetest.get_meta(pos)
		lottplayer.inv_update(sender, fields)
		meta:set_string("formspec",
			lottplayer.inv_size("4x6") .. lottplayer.inv(sender) .. tool_form())

		if fields.quit then
			lottplayer.inv_quit(sender)
		end
	end,
	allow_metadata_inventory_move = function()
		return 0
	end,
	allow_metadata_inventory_put = function(pos, listname, index, stack)
		local inv = minetest.get_meta(pos):get_inventory()
		if not inv:is_empty(listname) then
			return 0
		end
		local item_name = stack:get_name()
		if listname == "tool_head" then
			if minetest.get_item_group(item_name, "tool_head") ~= 0 then
				return 1
			end
		elseif listname == "tool_binding" then
			if minetest.get_item_group(item_name, "tool_binding") ~= 0 then
				return 1
			end
		elseif listname == "tool_handle" then
			if minetest.get_item_group(item_name, "tool_handle") ~= 0 then
				return 1
			end
		end
		return 0
	end,
	groups = {axe = 1},
})

-- Tmp dig all pick!
minetest.register_tool("lotttools:omni_pick", {
	description = "Digs all!",
	inventory_image = "lotttools_pick.png",
	tool_capabilities = {
		full_punch_interval = 0.5,
		groupcaps = {
			pickaxe = {maxlevel = 0, uses = 100,
				times = {[1] = 0.5, [2] = 0.75, [3] = 1, [4] = 0.2}},
			axe = {maxlevel = 0, uses = 100,
				times = {[1] = 0.5, [2] = 0.75, [3] = 1, [4] = 0.2}},
			plant = {maxlevel = 0, uses = 100,
				times = {[1] = 0.5, [2] = 0.75, [3] = 1, [4] = 0.2}},
		}
	},
})
